==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Summary.java <==
package com.example.model;

/**
 * Model for Summary
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "Summary", description = "Model for Summary")
@javax.xml.bind.annotation.XmlRootElement(name = "Summary")
public class Summary implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String name = null;
	private java.lang.String value = null;
	
	/**
	 */
	public Summary name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	@javax.validation.constraints.NotNull
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Summary value(java.lang.String value) {
		setValue(value);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("value")
	public java.lang.String getValue() {
		return this.value;
	}
	public void setValue(java.lang.String value) {
		this.value = value;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Summary summary = (Summary) o;
		return java.util.Objects.equals(this.name, summary.name)
				&& java.util.Objects.equals(this.value, summary.value);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.name, this.value);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Summary {\n");
		
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    value: ").append(toIndentedString(this.value)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Summary.java <==
package com.example.model;

/**
 * Model for Summary
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Summary", description = "Model for Summary")
@javax.xml.bind.annotation.XmlRootElement(name = "Summary")
public class Summary implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String name = null;
	private java.lang.String value = null;
	
	/**
	 */
	public Summary name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "name")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	@javax.validation.constraints.NotNull
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Summary value(java.lang.String value) {
		setValue(value);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "value")
	@com.fasterxml.jackson.annotation.JsonProperty("value")
	public java.lang.String getValue() {
		return this.value;
	}
	public void setValue(java.lang.String value) {
		this.value = value;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Summary summary = (Summary) o;
		return java.util.Objects.equals(this.name, summary.name)
				&& java.util.Objects.equals(this.value, summary.value);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.name, this.value);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Summary {\n");
		
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    value: ").append(toIndentedString(this.value)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
